/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * HarmonicSound.hpp
 *
 *  Created on: 2010/12/09
 *      Author: HARK Development Team
 */

#ifndef HARMONICSOUND_HPP_
#define HARMONICSOUND_HPP_

#include <vector>
#include <boost/shared_ptr.hpp>
#include <EventID.hpp>
#include <Band.hpp>
#include <BandAndHarmonicRatio.hpp>
#include <AngleAndProbability.hpp>

namespace NSHarkBinaural
{

struct HarmonicSound
{
    /**
     * イベントID.
     */
    //int eventID;
    EventID eventID;

    /**
     * 基底周波数のバンド.
     */
    //Band fundamental;

    /**
     * 候補の個数.
     */
    //int candidateCount;

    /**
     * この音の方向と確率.
     * 確率の大きい順にソートされている
     */
    boost::shared_ptr<std::vector<std::pair<size_t, Probability> > > directions;

    /**
     * 調波構造を構成するのバンドの配列.
     * 先頭要素が基底バンドで、その後に2倍音、3倍音と続く。
     * 配列のサイズは存在する倍音の数と等しくなる。配列のサイズと最高倍音の倍率は等しくない。
     * 途中の倍音が存在しない場合があるからである。
     */
    boost::shared_ptr<std::vector<BandAndHarmonicRatio> > bands;        /* bands of harmonics */

    //int harmsl[MAXHARM];        /* bands of harmonics left channel */
    //int harmsr[MAXHARM];        /* bands of harmonics right channel */
    //double dirs[MAXHARM];      /* direction of harmonics */

    HarmonicSound()
        : directions(new std::vector<std::pair<size_t, Probability> >()), bands(new std::vector<BandAndHarmonicRatio>())
    { }
};

}

#endif /* HARMONICSOUND_HPP_ */
